@@ -36,8 +36,7 @@
  *	@(#)queue.h	8.5 (Berkeley) 8/20/94
  */
 
-#ifndef	_SYS_QUEUE_H_
-#define	_SYS_QUEUE_H_
+#pragma once
 
 /*
  * This file defines five types of data structures: singly-linked lists, 
@@ -507,5 +506,3 @@ struct {								\
 	else								\
 		(elm2)->field.cqe_prev->field.cqe_next = (elm2);	\
 } while (0)
-
-#endif /* !_SYS_QUEUE_H_ */
