@@ -7,22 +7,19 @@
  */
 
 #include "config.h"
-
-#include <stdio.h>
+#include "mod.h"
+#include "pkt.h"
 #include <stdlib.h>
 #include <string.h>
 
-#include "pkt.h"
-#include "mod.h"
-
-#define DELAY_FIRST    1
-#define DELAY_LAST    2
-#define DELAY_RANDOM    3
+#define DELAY_FIRST 1
+#define DELAY_LAST 2
+#define DELAY_RANDOM 3
 
 struct delay_data {
-    rand_t        *rnd;
-    int         which;
-    struct timeval     tv;
+    rand_t *rnd;
+    int which;
+    struct timeval tv;
 };
 
 void *
@@ -60,12 +57,12 @@ delay_open(int argc, char *argv[])
     else
         return (delay_close(data));
 
-    if ((usec = atoi(argv[2])) == 0)
+    if ((usec = strtol(argv[2], NULL, 10)) == 0)
         return (delay_close(data));
 
     usec *= 1000;
-    data->tv.tv_sec = usec / 1000000;
-    data->tv.tv_usec = usec % 1000000;
+    data->tv.tv_sec = (time_t)(usec / 1000000);
+    data->tv.tv_usec = (suseconds_t)(usec % 1000000);
 
     return (data);
 }
@@ -89,9 +86,9 @@ delay_apply(void *d, struct pktq *pktq)
 }
 
 struct mod mod_delay = {
-    "delay",            /* name */
-    "delay first|last|random <ms>",    /* usage */
-    delay_open,            /* open */
-    delay_apply,           /* apply */
-    delay_close            /* close */
+        "delay",                        /* name */
+        "delay first|last|random <ms>", /* usage */
+        delay_open,                     /* open */
+        delay_apply,                    /* apply */
+        delay_close                     /* close */
 };
