@@ -7,22 +7,19 @@
  */
 
 #include "config.h"
-
-#include <stdio.h>
+#include "mod.h"
+#include "pkt.h"
 #include <stdlib.h>
 #include <string.h>
 
-#include "pkt.h"
-#include "mod.h"
-
-#define DROP_FIRST    1
-#define DROP_LAST    2
-#define DROP_RANDOM    3
+#define DROP_FIRST 1
+#define DROP_LAST 2
+#define DROP_RANDOM 3
 
 struct drop_data {
-    rand_t    *rnd;
-    int     which;
-    int     percent;
+    rand_t *rnd;
+    int which;
+    int percent;
 };
 
 void *
@@ -59,7 +56,7 @@ drop_open(int argc, char *argv[])
     else
         return (drop_close(data));
 
-    if ((data->percent = atoi(argv[2])) <= 0 || data->percent > 100)
+    if ((data->percent = (int)strtol(argv[2], NULL, 10)) <= 0 || data->percent > 100)
         return (drop_close(data));
 
     return (data);
@@ -71,8 +68,7 @@ drop_apply(void *d, struct pktq *pktq)
     struct drop_data *data = (struct drop_data *)d;
     struct pkt *pkt;
 
-    if (data->percent < 100 &&
-        (rand_uint16(data->rnd) % 100) > data->percent)
+    if (data->percent < 100 && (rand_uint16(data->rnd) % 100) > data->percent)
         return (0);
 
     if (data->which == DROP_FIRST)
@@ -91,9 +87,9 @@ drop_apply(void *d, struct pktq *pktq)
 }
 
 struct mod mod_drop = {
-    "drop",                    /* name */
-    "drop first|last|random <prob-%>",    /* usage */
-    drop_open,                /* open */
-    drop_apply,               /* apply */
-    drop_close                /* close */
+        "drop",                            /* name */
+        "drop first|last|random <prob-%>", /* usage */
+        drop_open,                         /* open */
+        drop_apply,                        /* apply */
+        drop_close                         /* close */
 };
