@@ -7,24 +7,22 @@
  */
 
 #include "config.h"
-
+#include "mod.h"
+#include "pkt.h"
+#include "randutil.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "mod.h"
-#include "pkt.h"
-#include "randutil.h"
-
-#define CHAFF_TYPE_DUP     1
-#define CHAFF_TYPE_OPT     2
-#define CHAFF_TYPE_TTL     3
+#define CHAFF_TYPE_DUP 1
+#define CHAFF_TYPE_OPT 2
+#define CHAFF_TYPE_TTL 3
 
 struct ip_chaff_data {
-    rand_t        *rnd;
-    int         type;
-    int         ttl;
-    struct pktq    *pktq;
+    rand_t *rnd;
+    int type;
+    int ttl;
+    struct pktq *pktq;
 };
 
 void *
@@ -56,8 +54,8 @@ ip_chaff_open(int argc, char *argv[])
         data->type = CHAFF_TYPE_DUP;
     } else if (strcasecmp(argv[1], "opt") == 0) {
         data->type = CHAFF_TYPE_OPT;
-    } else if ((data->ttl = atoi(argv[1])) >= 0 && data->ttl < 256) {
-                data->type = CHAFF_TYPE_TTL;
+    } else if ((data->ttl = strtol(argv[1], NULL, 10)) >= 0 && data->ttl < 256) {
+        data->type = CHAFF_TYPE_TTL;
     } else
         return (ip_chaff_close(data));
 
@@ -80,39 +78,33 @@ ip_chaff_apply(void *d, struct pktq *pktq)
             continue;
 
         new = pkt_dup(pkt);
-        rand_strset(data->rnd, new->pkt_ip_data,
-            new->pkt_end - new->pkt_ip_data + 1);
+        rand_strset(data->rnd, new->pkt_ip_data, new->pkt_end - new->pkt_ip_data + 1);
 
         switch (data->type) {
         case CHAFF_TYPE_DUP:
             new->pkt_ts.tv_usec = 1;
             if (eth_type == ETH_TYPE_IP) {
-            ip_checksum(new->pkt_ip, new->pkt_ip_data -
-                new->pkt_eth_data);
+                ip_checksum(new->pkt_ip, new->pkt_ip_data - new->pkt_eth_data);
             }
             break;
         case CHAFF_TYPE_OPT:
             if (eth_type == ETH_TYPE_IP) {
-            opt.opt_type = 0x42;
-            opt.opt_len = IP_OPT_LEN;
-            i = ip_add_option(new->pkt_ip,
-                new->pkt_buf_size - ETH_HDR_LEN, IP_PROTO_IP,
-                &opt, opt.opt_len);
-            /* XXX - whack opt with random crap */
-            *(uint32_t *)new->pkt_ip_data = rand_uint32(data->rnd);
-            new->pkt_ip_data += i;
-            new->pkt_end += i;
-            ip_checksum(new->pkt_ip, new->pkt_ip_data -
-                new->pkt_eth_data);
+                opt.opt_type = 0x42;
+                opt.opt_len = IP_OPT_LEN;
+                i = ip_add_option(new->pkt_ip, new->pkt_buf_size - ETH_HDR_LEN, IP_PROTO_IP, &opt, opt.opt_len);
+                /* XXX - whack opt with random crap */
+                *(uint32_t *)new->pkt_ip_data = rand_uint32(data->rnd);
+                new->pkt_ip_data += i;
+                new->pkt_end += i;
+                ip_checksum(new->pkt_ip, new->pkt_ip_data - new->pkt_eth_data);
             } else if (eth_type == ETH_TYPE_IPV6) {
                 continue;
             }
-            /* no break */
+            /* fall through */
         case CHAFF_TYPE_TTL:
             if (eth_type == ETH_TYPE_IP) {
-            new->pkt_ip->ip_ttl = data->ttl;
-            ip_checksum(new->pkt_ip, new->pkt_ip_data -
-                new->pkt_eth_data);
+                new->pkt_ip->ip_ttl = data->ttl;
+                ip_checksum(new->pkt_ip, new->pkt_ip_data - new->pkt_eth_data);
             } else if (eth_type == ETH_TYPE_IPV6) {
                 pkt->pkt_ip6->ip6_hlim = data->ttl;
             }
@@ -129,9 +121,9 @@ ip_chaff_apply(void *d, struct pktq *pktq)
 }
 
 struct mod mod_ip_chaff = {
-    "ip_chaff",                /* name */
-    "ip_chaff dup|opt|<ttl>",        /* usage */
-    ip_chaff_open,                /* open */
-    ip_chaff_apply,                /* apply */
-    ip_chaff_close                /* close */
+        "ip_chaff",               /* name */
+        "ip_chaff dup|opt|<ttl>", /* usage */
+        ip_chaff_open,            /* open */
+        ip_chaff_apply,           /* apply */
+        ip_chaff_close            /* close */
 };
