@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2024 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2025 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it
  *   and/or modify it under the terms of the GNU General Public License as
@@ -37,6 +37,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
 
 #ifdef DEBUG
 int debug;
@@ -102,6 +105,22 @@ main(int argc, char *argv[])
     /* open up the output file */
     options.outfile = safe_strdup(OPT_ARG(OUTFILE));
     dbgx(1, "Rewriting DLT to %s", pcap_datalink_val_to_name(tcpedit_get_output_dlt(tcpedit)));
+
+#ifdef HAVE_SYS_STAT_H
+    /* if the output file exists, make sure it isn't also the input file */
+    struct stat outfile_stat;
+    if (stat(options.outfile, &outfile_stat) == 0) {
+        struct stat infile_stat;
+        if (stat(options.infile, &infile_stat) == 0) {
+            if (outfile_stat.st_ino == infile_stat.st_ino) {
+                /* they are the same file */
+                tcpedit_close(&tcpedit);
+                err(-1, "--infile and --outfile cannot be the same file");
+            }
+        }
+    }
+#endif
+
     if ((dlt_pcap = pcap_open_dead(tcpedit_get_output_dlt(tcpedit), 65535)) == NULL) {
         tcpedit_close(&tcpedit);
         err(-1, "Unable to open dead pcap handle.");
@@ -273,6 +292,8 @@ rewrite_packets(tcpedit_t *tcpedit_ctx, pcap_t *pin, pcap_dumper_t *pout)
 
         if (pkthdr.caplen > MAX_SNAPLEN)
             errx(-1, "Frame too big, caplen %d exceeds %d", pkthdr.caplen, MAX_SNAPLEN);
+        if (pkthdr.len > MAX_SNAPLEN)
+            errx(-1, "Frame too big, len %d exceeds %d", pkthdr.len, MAX_SNAPLEN);
         /*
          * copy over the packet so we can pad it out if necessary and
          * because pcap_next() returns a const ptr
